[−][src]Enum pallet_session::Call
Dispatchable calls.
Each variant of this enum maps to a dispatchable function from the associated module.
Variants
Sets the session key(s) of the function caller to keys.
Allows an account to set its session key prior to becoming a validator.
This doesn't take effect until the next session.
The dispatch origin of this function must be signed.
- O(log n) in number of accounts.
- One extra DB entry.
- Increases system account refs by one on success iff there were previously no keys set. In this case, purge_keys will need to be called before the account can be removed.
Removes any session key(s) of the function caller. This doesn't take effect until the next session.
The dispatch origin of this function must be signed.
- O(N) in number of key types.
- Removes N + 1 DB entries.
- Reduces system account refs by one on success.