ExternallySetKeys

Type Alias ExternallySetKeys 

pub type ExternallySetKeys<T: Config> = StorageMap<_GeneratedPrefixForStorageExternallySetKeys<T>, Twox64Concat, T::AccountId, (), OptionQuery>;
Accounts whose keys were set via SessionInterface (external path) without incrementing the consumer reference or placing a key deposit. do_purge_keys only decrements consumers for accounts that were registered through the local session pallet.

Storage type is StorageMap with key type T :: AccountId and value type ().

Aliased Type

pub struct ExternallySetKeys<T: Config>(/* private fields */);