QueuedChanged

Type Alias QueuedChanged 

pub type QueuedChanged<T> = StorageValue<_GeneratedPrefixForStorageQueuedChanged<T>, bool, ValueQuery>;
True if the underlying economic identities or weighting behind the validators has changed in the queued validator set.

Storage type is StorageValue with value type bool.

Aliased Type

pub struct QueuedChanged<T>(/* private fields */);