[][src]Struct pallet_session::Module

pub struct Module<T: Trait>(_);

Methods

impl<T: Trait + 'static> Module<T>[src]

pub fn validators() -> Vec<T::ValidatorId>[src]

The current set of validators.

pub fn current_index() -> SessionIndex[src]

Current index of the session.

pub fn queued_keys() -> Vec<(T::ValidatorId, T::Keys)>[src]

The queued keys for the next session. When the next session begins, these keys will be used to determine the validator's session keys.

pub fn disabled_validators() -> Vec<u32>[src]

Indices of disabled validators.

The set is cleared when on_session_ending returns a new set of identities.

impl<T: Trait> Module<T>[src]

Can also be called using Call.

pub fn set_keys(
    origin: T::Origin,
    keys: T::Keys,
    proof: Vec<u8>
) -> DispatchResult
[src]

Sets the session key(s) of the function caller to keys. Allows an account to set its session key prior to becoming a validator. This doesn't take effect until the next session.

The dispatch origin of this function must be signed.

  • O(log n) in number of accounts.
  • One extra DB entry.
  • Increases system account refs by one on success iff there were previously no keys set. In this case, purge_keys will need to be called before the account can be removed.

pub fn purge_keys(origin: T::Origin) -> DispatchResult[src]

Removes any session key(s) of the function caller. This doesn't take effect until the next session.

The dispatch origin of this function must be signed.

  • O(N) in number of key types.
  • Removes N + 1 DB entries.
  • Reduces system account refs by one on success.

impl<T: Trait> Module<T>[src]

pub fn rotate_session()[src]

Move on to next session. Register new validator set and session keys. Changes to the validator set have a session of delay to take effect. This allows for equivocation punishment after a fork.

pub fn disable_index(i: usize) -> bool[src]

Disable the validator of index i.

Returns true if this causes a DisabledValidatorsThreshold of validators to be already disabled.

pub fn disable(c: &T::ValidatorId) -> Result<bool, ()>[src]

Disable the validator identified by c. (If using with the staking module, this would be their stash account.)

Returns Ok(true) if more than DisabledValidatorsThreshold validators in current session is already disabled. If used with the staking module it allows to force a new era in such case.