Implementation of DisablingStrategy using factor_based_disable_limit which disables
validators from the active set up to a threshold. DISABLING_LIMIT_FACTOR is the factor of the
maximum disabled validators in the active set. E.g. setting this value to 3 means no more than
1/3 of the validators in the active set can be disabled in an era.
Implementation of DisablingStrategy which disables validators from the active set up to a
limit (factor_based_disable_limit) and if the limit is reached and the new offender is higher
(bigger punishment/severity) then it re-enables the lowest offender to free up space for the new
offender.