[−][src]Enum pallet_session::Event
Events for this module.
Variants
NewSession(SessionIndex)New session has happened. Note that the argument is the session index, not the block number as the type might suggest.